@@ -26,7 +26,7 @@
 #include <limits>
 
 #include <QGraphicsTextItem>
-#include <QPainter>
+#include <QFont>
 
 qreal KFontUtils::adaptFontSize(QGraphicsTextItem* string, qreal width, qreal height, qreal maxFontSize, qreal minFontSize, qreal precision)
 {
